<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="is_IS">
<context>
    <name>Dialog</name>
    <message>
        <source>Perturbation:</source>
        <translation>Truflun:</translation>
    </message>
    <message>
        <source>Julia-seed:</source>
        <translation>Júlíu-fræ:</translation>
    </message>
    <message>
        <source>Morphing type:</source>
        <translation>Mótunargerð (morphing type):</translation>
    </message>
    <message>
        <source>Startuptime:</source>
        <translation>Byrjunartími:</translation>
    </message>
    <message>
        <source>Stoptime:</source>
        <translation>Endatími:</translation>
    </message>
    <message>
        <source>File to render:</source>
        <translation type="vanished">Skjöl til frágangs:</translation>
    </message>
    <message>
        <source>Basename:</source>
        <translation>Grunnnafn:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Breidd:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Hæð:</translation>
    </message>
    <message>
        <source>Pixel width (cm):</source>
        <translation>Pixel-breidd (cm):</translation>
    </message>
    <message>
        <source>Pixel height (cm):</source>
        <translation>Pixel-hæð (cm):</translation>
    </message>
    <message>
        <source>Framerate:</source>
        <translation>Fjöldi ramma á mínútu:</translation>
    </message>
    <message>
        <source>Image type:</source>
        <translation>Gerð myndar:</translation>
    </message>
    <message>
        <source>Antialiasing:</source>
        <translation>Afstöllun:</translation>
    </message>
    <message>
        <source>Always recalculate:</source>
        <translation>Endurreikna ávallt:</translation>
    </message>
    <message>
        <source>Center:</source>
        <translation>Miðja:</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Geisli:</translation>
    </message>
    <message>
        <source>Angle:</source>
        <translation>Horn:</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Hamur:</translation>
    </message>
    <message>
        <source>Start:</source>
        <translation>Byrjun:</translation>
    </message>
    <message>
        <source>End:</source>
        <translation>Endir:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Litur:</translation>
    </message>
    <message>
        <source>Rotations per second:</source>
        <translation>Snúningar á sekúndu:</translation>
    </message>
    <message>
        <source>Letters per second:</source>
        <translation>Stafir á sekúndu:</translation>
    </message>
    <message>
        <source>Iterations:</source>
        <translation>Ítranir:</translation>
    </message>
    <message>
        <source>Text:</source>
        <translation>Texti:</translation>
    </message>
    <message>
        <source>Your command:</source>
        <translation>Skipunin þín:</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Skráarheiti:</translation>
    </message>
    <message>
        <source>Formula:</source>
        <translation>Formúla:</translation>
    </message>
    <message>
        <source>X center:</source>
        <translation>X miðja:</translation>
    </message>
    <message>
        <source>Y center:</source>
        <translation>Y miðja:</translation>
    </message>
    <message>
        <source>X Radius:</source>
        <translation>X Geisli:</translation>
    </message>
    <message>
        <source>Y Radius:</source>
        <translation>Y Geisli:</translation>
    </message>
    <message>
        <source>Coordinates:</source>
        <translation>Hnit:</translation>
    </message>
    <message>
        <source>continuous rotation</source>
        <translation>samfelldur snúningur</translation>
    </message>
    <message>
        <source>Fast rotation</source>
        <translation>Hraður snúningur</translation>
    </message>
    <message>
        <source>filter</source>
        <translation>sía</translation>
    </message>
    <message>
        <source>enable</source>
        <translation>leyfa</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Fjöldi:</translation>
    </message>
    <message>
        <source>Zooming speed:</source>
        <translation>Þysjunarhraði:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nafn:</translation>
    </message>
    <message>
        <source>Bailout:</source>
        <translation>Stöðvunargildi (bailout):</translation>
    </message>
    <message>
        <source>Threads:</source>
        <translation>Þræðir:</translation>
    </message>
    <message>
        <source>Julia mode:</source>
        <translation>Júlíu-hamur:</translation>
    </message>
    <message>
        <source>Horizontal position:</source>
        <translation>Lárétt staða:</translation>
    </message>
    <message>
        <source>Vertical position:</source>
        <translation>Lóðrétt staða:</translation>
    </message>
    <message>
        <source>Dynamic resolution:</source>
        <translation>Kvik upplausn:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Tími:</translation>
    </message>
    <message>
        <source>Number:</source>
        <translation>Fjöldi:</translation>
    </message>
    <message>
        <source>Algorithm number:</source>
        <translation>Reiknirit númer:</translation>
    </message>
    <message>
        <source>Seed:</source>
        <translation>Fræ:</translation>
    </message>
    <message>
        <source>Shift:</source>
        <translation>Hliðrun:</translation>
    </message>
    <message>
        <source>Frames per second:</source>
        <translation>Rammar á sekúndu:</translation>
    </message>
    <message>
        <source>Formula</source>
        <translation type="unfinished">Formúla</translation>
    </message>
    <message>
        <source>Initialization:</source>
        <translation>Frumstilling:</translation>
    </message>
    <message>
        <source>Files to render:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Palette Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Palette Config</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Error</name>
    <message>
        <source>renderanim: Width parameter must be positive integer in the range 0..4096</source>
        <translation>renderanim: Breiddar-gildi verður að vera jákvæð heiltala á bilinu 0..4096</translation>
    </message>
    <message>
        <source>renderanim: Height parameter must be positive integer in the range 0..4096</source>
        <translation>renderanim: Hæðar-gildi verður að vera jákvæð heiltala á bilinu 0..4096</translation>
    </message>
    <message>
        <source>renderanim: Invalid real width and height dimensions</source>
        <translation>renderanim: Ógild raungildi breiddar og hæðar</translation>
    </message>
    <message>
        <source>renderanim: invalid framerate</source>
        <translation>renderanim: ógildur fjöldi ramma á tímaeiningu</translation>
    </message>
    <message>
        <source>renderanim: antialiasing not supported in 256 color mode</source>
        <translation>renderanim: afstöllun ekki studd í 256 lita ham</translation>
    </message>
    <message>
        <source>animateview: Invalid viewpoint</source>
        <translation>animateview: Ógildur sjónarhóll</translation>
    </message>
    <message>
        <source>Invalid viewpoint</source>
        <translation>Ógildur sjónarhóll</translation>
    </message>
    <message>
        <source>Unknown palette type</source>
        <translation>Óþekkt gerð litavals</translation>
    </message>
    <message>
        <source>Initialization of color cycling failed.</source>
        <translation>Frumstilling litahringjar mistókst.</translation>
    </message>
    <message>
        <source>Try to enable palette emulation filter</source>
        <translation>Reyni að leyfa hermunarsíu litavals</translation>
    </message>
    <message>
        <source>Algorithm:%i seed:%i size:%i</source>
        <translation>Algrím:%i fræ:%i stærð:%i</translation>
    </message>
    <message>
        <source>line available only in animation replay</source>
        <translation>lína eingöngu aðgengileg í endurspilun hreyfimyndar</translation>
    </message>
    <message>
        <source>Morphing non existing line!</source>
        <translation>Myndbræðing línu sem ekki er til staðar!</translation>
    </message>
    <message>
        <source>linekey not available in this context!</source>
        <translation>Línulykill ekki aðgengilegur í þessu samhengi!</translation>
    </message>
    <message>
        <source>clear_line available only in animation replay</source>
        <translation>Línuhreynsun eingöngu aðgengileg í endurspilun hreyfimyndar</translation>
    </message>
    <message>
        <source>clear_lines available only in animation replay</source>
        <translation>Línuhreynsun eingöngu aðgengileg í endurspilun hreyfimyndar</translation>
    </message>
    <message>
        <source>Catalog file not found</source>
        <translation>Skjalið fannst ekki</translation>
    </message>
    <message>
        <source>Replay is already active</source>
        <translation>Endurspilun er nú þegar virk</translation>
    </message>
    <message>
        <source>File open failed</source>
        <translation>Opnun skjals mistókst</translation>
    </message>
    <message>
        <source>Out of memory</source>
        <translation>Minnið er búið</translation>
    </message>
    <message>
        <source>Missing parameter</source>
        <translation>Vantar stika</translation>
    </message>
    <message>
        <source>Unexpected end of file</source>
        <translation>Skjal endar óvænt</translation>
    </message>
    <message>
        <source>Token is too long</source>
        <translation>Of langur tóki</translation>
    </message>
    <message>
        <source>Unknown formula type</source>
        <translation>Óþekkt gerð formúlu</translation>
    </message>
    <message>
        <source>morph available only in animation replay</source>
        <translation>Bræðingsmynd eingöngu aðgengileg í endurspilun hreyfimyndar</translation>
    </message>
    <message>
        <source>morphview: Invalid viewpoint</source>
        <translation>morphview: Ógilt sjónarhorn</translation>
    </message>
    <message>
        <source>move available only in animation replay</source>
        <translation>færsla eingöngu aðgengileg í endurspilun hreyfimyndar</translation>
    </message>
    <message>
        <source>morphjulia available only in animation replay</source>
        <translation>morphjulia er eingöngu aðgengilegt í endurspilun hreyfimyndar</translation>
    </message>
    <message>
        <source>morphangle available only in animation replay</source>
        <translation>morphangle eingöngu aðgengilegt í endurspilun hreyfimyndar</translation>
    </message>
    <message>
        <source>Unknown filter</source>
        <translation>Óþekkt sía</translation>
    </message>
    <message>
        <source>sleep available only in animation replay</source>
        <translation>hvíld eingöngu aðgengileg í endurspilun hreyfimyndar</translation>
    </message>
    <message>
        <source>Internal program error #12 %i
</source>
        <translation>Innri villa forrits #12 %i
</translation>
    </message>
    <message>
        <source>wait available only in animation replay</source>
        <translation>bið eingöngu aðgengileg í endurspilun hreyfimyndar</translation>
    </message>
    <message>
        <source>No catalog file loaded</source>
        <translation>Ekkert skjal hlóðst</translation>
    </message>
    <message>
        <source>Message not found in catalog file</source>
        <translation>Skilaboð fundust ekki í skjalinu</translation>
    </message>
    <message>
        <source>load available only in animation replay</source>
        <translation>hlaða (load) eingöngu aðgengilegt í endurspilun hreyfimyndar</translation>
    </message>
    <message>
        <source>Include level overflow</source>
        <translation>Innihalda yfirflæði borðs (level)</translation>
    </message>
    <message>
        <source>File not found</source>
        <translation>Skjal fannst ekki</translation>
    </message>
    <message>
        <source>Too many parameters</source>
        <translation>Of margir stikar</translation>
    </message>
    <message>
        <source>Error: %s</source>
        <translation>Villa: %s</translation>
    </message>
    <message>
        <source>Cannot create palette</source>
        <translation>Get ekki útbúið litaval</translation>
    </message>
    <message>
        <source>Cannot create image
</source>
        <translation>Get ekki útbúið mynd
</translation>
    </message>
    <message>
        <source>Cannot create checking buffer!</source>
        <translation>Get ekki útbúið prófunar-biðminni!</translation>
    </message>
    <message>
        <source>Cannot create context
</source>
        <translation>Get ekki útbúið samhengi
</translation>
    </message>
    <message>
        <source>Cannot open animation file
</source>
        <translation>Get ekki opnað skjal hreyfimyndar
</translation>
    </message>
    <message>
        <source>Calculation interrupted</source>
        <translation>Útreikningar truflaðir</translation>
    </message>
    <message>
        <source>Calculation finished</source>
        <translation>Útreikningum lokið</translation>
    </message>
    <message>
        <source>Tutorial files not found. Reinstall XaoS</source>
        <translation>Leiðbeiningarskjöl fundust ekki. Enduruppsetjið XaoS (reinstall)</translation>
    </message>
    <message>
        <source>Could not open examples</source>
        <translation>Gat ekki opnað dæmi</translation>
    </message>
    <message>
        <source>Can not create palette</source>
        <translation>Get ekki útbúið litaval</translation>
    </message>
    <message>
        <source>XaoS is out of memory.</source>
        <translation>XaoS búið með minnið.</translation>
    </message>
    <message>
        <source>Can not create image</source>
        <translation>Get ekki útbúið mynd</translation>
    </message>
    <message>
        <source>Can not allocate tables</source>
        <translation>Get ekki úthlutað töflum</translation>
    </message>
    <message>
        <source>Could not open image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Root menu</source>
        <translation>Rótarvalmynd</translation>
    </message>
    <message>
        <source>Animation root menu</source>
        <translation>Rótarvalmynd hreyfimyndar</translation>
    </message>
    <message>
        <source>Replay only commands</source>
        <translation>Endurspila skipanir eingöngu</translation>
    </message>
    <message>
        <source>Line drawing functions</source>
        <translation>Línuteikningarföll</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Lína</translation>
    </message>
    <message>
        <source>Morph line</source>
        <translation>Bræðingsmynd línu</translation>
    </message>
    <message>
        <source>Morph last line</source>
        <translation>Bræðingsmynd síðustu línu</translation>
    </message>
    <message>
        <source>Set line key</source>
        <translation>Skilgreina lykil línu</translation>
    </message>
    <message>
        <source>Clear line</source>
        <translation>Eyða línu</translation>
    </message>
    <message>
        <source>Clear all lines</source>
        <translation>Eyða öllum línum</translation>
    </message>
    <message>
        <source>Animation functions</source>
        <translation>Aðgerðir hreyfimyndar</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Notandasýn</translation>
    </message>
    <message>
        <source>Morph view</source>
        <translation>Sýn bræðingsmyndar</translation>
    </message>
    <message>
        <source>Morph julia</source>
        <translation>Bræðingsmynd Júlíu</translation>
    </message>
    <message>
        <source>Move view</source>
        <translation>Sýn hreyfingar</translation>
    </message>
    <message>
        <source>Morph angle</source>
        <translation>Bræðingsmynd horns</translation>
    </message>
    <message>
        <source>Zoom center</source>
        <translation>Þysjunarmiðja</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Þysja inn</translation>
    </message>
    <message>
        <source>Un-zoom</source>
        <translation>Þysja út</translation>
    </message>
    <message>
        <source>Stop zooming</source>
        <translation>Stöðva þysjun</translation>
    </message>
    <message>
        <source>Smooth morphing parameters</source>
        <translation>Samfelldir stikar bræðingsmyndar</translation>
    </message>
    <message>
        <source>Timing functions</source>
        <translation>Tímasetningarföll</translation>
    </message>
    <message>
        <source>Usleep</source>
        <translation>Usleep</translation>
    </message>
    <message>
        <source>Wait for text</source>
        <translation>Bið eftir texta</translation>
    </message>
    <message>
        <source>Wait for complete image</source>
        <translation>Bið eftir tilbúinni mynd</translation>
    </message>
    <message>
        <source>Include file</source>
        <translation>Fella inn skrá</translation>
    </message>
    <message>
        <source>Default palette</source>
        <translation>Sjálfgefið litaval</translation>
    </message>
    <message>
        <source>Formula</source>
        <translation>Formúla</translation>
    </message>
    <message>
        <source>Maximal zooming step</source>
        <translation>Stærsta þysjunarskref</translation>
    </message>
    <message>
        <source>Zooming speedup</source>
        <translation>Þysjunarhraði</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Sía</translation>
    </message>
    <message>
        <source>Letters per second</source>
        <translation>Stafir á sekúndu</translation>
    </message>
    <message>
        <source>Interrupt</source>
        <translation>Trufla</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Staða</translation>
    </message>
    <message>
        <source>Ministatus</source>
        <translation>Örstaða</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Skrá</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Breyta</translation>
    </message>
    <message>
        <source>Fractal</source>
        <translation>Broti</translation>
    </message>
    <message>
        <source>Calculation</source>
        <translation>Útreikningar</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Síur</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Aðgerð</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aðstoð</translation>
    </message>
    <message>
        <source>Tutorials</source>
        <translation>Leiðbeiningar</translation>
    </message>
    <message>
        <source>Stop replay</source>
        <translation>Stöðva endurspilun</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Skipun</translation>
    </message>
    <message>
        <source>Play string</source>
        <translation>Spila streng</translation>
    </message>
    <message>
        <source>Clear screen</source>
        <translation>Hreinsa skjá</translation>
    </message>
    <message>
        <source>Display fractal</source>
        <translation>Sýna brota</translation>
    </message>
    <message>
        <source>Display text</source>
        <translation>Sýna texta</translation>
    </message>
    <message>
        <source>Text color</source>
        <translation>Litur texta</translation>
    </message>
    <message>
        <source>Horizontal text position</source>
        <translation>Lárétt staða texta</translation>
    </message>
    <message>
        <source>Vertical text position</source>
        <translation>Lóðrétt staða texta</translation>
    </message>
    <message>
        <source>Text position</source>
        <translation>Staða texta</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Skilaboð</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nýtt</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Opna</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Upptaka</translation>
    </message>
    <message>
        <source>Replay</source>
        <translation>Endurspila</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation type="vanished">Vista mynd</translation>
    </message>
    <message>
        <source>Render</source>
        <translation>Ganga frá</translation>
    </message>
    <message>
        <source>Load random example</source>
        <translation>Hlaða slembivöldu dæmi</translation>
    </message>
    <message>
        <source>Save configuration</source>
        <translation>Vista stöðu</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Til baka</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Endurgera</translation>
    </message>
    <message>
        <source>Formulae</source>
        <translation>Formúlur</translation>
    </message>
    <message>
        <source>More formulae</source>
        <translation>Fleiri formúlur</translation>
    </message>
    <message>
        <source>User formula</source>
        <translation>Notendaformúla</translation>
    </message>
    <message>
        <source>User initialization</source>
        <translation>Frumstilling notanda</translation>
    </message>
    <message>
        <source>Incoloring mode</source>
        <translation>Innlitahamur</translation>
    </message>
    <message>
        <source>Outcoloring mode</source>
        <translation>Útlitahamur</translation>
    </message>
    <message>
        <source>Plane</source>
        <translation>Slétta</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation>Litaval</translation>
    </message>
    <message>
        <source>Mandelbrot mode</source>
        <translation>Mandelbrot hamur</translation>
    </message>
    <message>
        <source>Julia mode</source>
        <translation>Júlíu hamur</translation>
    </message>
    <message>
        <source>Fast julia mode</source>
        <translation>Hrað júlíu hamur</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>Snúningur</translation>
    </message>
    <message>
        <source>Set angle</source>
        <translation>Stilla horn</translation>
    </message>
    <message>
        <source>Set plane</source>
        <translation>Stilla sléttu</translation>
    </message>
    <message>
        <source>Inside coloring mode</source>
        <translation>Innra litaspjald</translation>
    </message>
    <message>
        <source>Outside coloring mode</source>
        <translation>Ytra litaspjald</translation>
    </message>
    <message>
        <source>Inside truecolor coloring mode</source>
        <translation>Innra sannlita litaspjald</translation>
    </message>
    <message>
        <source>Outside truecolor coloring mode</source>
        <translation>Ytra sannlita litaspjald</translation>
    </message>
    <message>
        <source>Julia seed</source>
        <translation>Júlíu fræ</translation>
    </message>
    <message>
        <source>Random palette</source>
        <translation>Slembival lita</translation>
    </message>
    <message>
        <source>Custom palette</source>
        <translation>Sérval lita</translation>
    </message>
    <message>
        <source>Color cycling</source>
        <translation>Litarás</translation>
    </message>
    <message>
        <source>Reversed color cycling</source>
        <translation>Öfug litarás</translation>
    </message>
    <message>
        <source>Color cycling speed</source>
        <translation>Hraði litarásar</translation>
    </message>
    <message>
        <source>Shift palette</source>
        <translation>Hliðra litavali</translation>
    </message>
    <message>
        <source>Shift one forward</source>
        <translation>Hliðra einn áfram</translation>
    </message>
    <message>
        <source>Shift one backward</source>
        <translation>Hliðra einn afturábak</translation>
    </message>
    <message>
        <source>Solid guessing</source>
        <translation>Gisk fyrir rúmskika</translation>
    </message>
    <message>
        <source>Disable solid guessing</source>
        <translation>Afnema gisk fyrir rúmskika</translation>
    </message>
    <message>
        <source>Guess 2x2 rectangles</source>
        <translation>Giska 2x2 ferhyrningar</translation>
    </message>
    <message>
        <source>Guess 3x3 rectangles</source>
        <translation>Giska 3x3 ferhyrningar</translation>
    </message>
    <message>
        <source>Guess 4x4 rectangles</source>
        <translation>Giska 4x4 ferhyrningar</translation>
    </message>
    <message>
        <source>Guess 5x5 rectangles</source>
        <translation>Giska 5x5 ferhyrningar</translation>
    </message>
    <message>
        <source>Guess 6x6 rectangles</source>
        <translation>Giska 6x6 ferhyrningar</translation>
    </message>
    <message>
        <source>Guess 7x7 rectangles</source>
        <translation>Giska 7x7 ferhyrningar</translation>
    </message>
    <message>
        <source>Guess 8x8 rectangles</source>
        <translation>Giska 8x8 ferhyrningar</translation>
    </message>
    <message>
        <source>Guess unlimited rectangles</source>
        <translation>Giska ótakmarkaða ferhyrninga</translation>
    </message>
    <message>
        <source>Dynamic resolution</source>
        <translation>Kvik upplausn</translation>
    </message>
    <message>
        <source>Periodicity checking</source>
        <translation>Tímaspannsprufun</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Þræðir</translation>
    </message>
    <message>
        <source>Iterations</source>
        <translation>Ítranir</translation>
    </message>
    <message>
        <source>Bailout</source>
        <translation>Stöðvunargildi</translation>
    </message>
    <message>
        <source>Perturbation</source>
        <translation>Truflun (perturbation)</translation>
    </message>
    <message>
        <source>Zooming speed</source>
        <translation>Þysjunarhraði</translation>
    </message>
    <message>
        <source>Fixed step</source>
        <translation>Föst skref</translation>
    </message>
    <message>
        <source>Solid guessing range</source>
        <translation>Mörk giskunar rúmskika</translation>
    </message>
    <message>
        <source>Disable rotation</source>
        <translation>Gera snúning óvirkan</translation>
    </message>
    <message>
        <source>Continuous rotation</source>
        <translation>Samfelldur snúningur</translation>
    </message>
    <message>
        <source>Rotate by mouse</source>
        <translation>Snúa með mús</translation>
    </message>
    <message>
        <source>Rotation speed</source>
        <translation>Snúningshraði</translation>
    </message>
    <message>
        <source>Automatic rotation</source>
        <translation>Sjálfvirkur snúningur</translation>
    </message>
    <message>
        <source>Fast rotation mode</source>
        <translation>Hraður snúningshamur</translation>
    </message>
    <message>
        <source>Recalculate</source>
        <translation>Endurreikna</translation>
    </message>
    <message>
        <source>Disable dynamic resolution</source>
        <translation>Gera kvika upplausn óvirka</translation>
    </message>
    <message>
        <source>Use only during animation</source>
        <translation>Nota eingöngu meðan á hreyfimynd stendur</translation>
    </message>
    <message>
        <source>Use also for new images</source>
        <translation>Nota einnig fyrir nýjar myndir</translation>
    </message>
    <message>
        <source>Dynamic resolution mode</source>
        <translation>Hamur kvikrar upplausnar</translation>
    </message>
    <message>
        <source>Autopilot</source>
        <translation>Sjálfvirk stilling (autopilot)</translation>
    </message>
    <message>
        <source>Hide Messages</source>
        <translation>Fela skilaboð</translation>
    </message>
    <message>
        <source>An introduction to fractals</source>
        <translation>Inngangur að brotum (fractals)</translation>
    </message>
    <message>
        <source>XaoS features overview</source>
        <translation>Yfirlit XaoS möguleika</translation>
    </message>
    <message>
        <source>Math behind fractals</source>
        <translation>Stærðfræði að baki brotum (fractals)</translation>
    </message>
    <message>
        <source>Other fractal types in XaoS</source>
        <translation>Aðrar gerðir brota (fractals) í XaoS</translation>
    </message>
    <message>
        <source>What&apos;s new?</source>
        <translation>Hvað er nýtt?</translation>
    </message>
    <message>
        <source>Whole story</source>
        <translation>Sagan öll</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>Inngangur</translation>
    </message>
    <message>
        <source>Mandelbrot set</source>
        <translation>Mandelbrot mengið</translation>
    </message>
    <message>
        <source>Julia set</source>
        <translation>Júlíu mengið</translation>
    </message>
    <message>
        <source>Higher power Mandelbrots</source>
        <translation>Æðri velda Mandelbrot</translation>
    </message>
    <message>
        <source>Newton&apos;s method</source>
        <translation>Aðferð Newtons</translation>
    </message>
    <message>
        <source>Barnsley&apos;s formula</source>
        <translation>Formúla Barnsleys</translation>
    </message>
    <message>
        <source>Phoenix</source>
        <translation>Fönix (Phoenix)</translation>
    </message>
    <message>
        <source>Octo</source>
        <translation>Áttu (octo)</translation>
    </message>
    <message>
        <source>Magnet</source>
        <translation>Segull</translation>
    </message>
    <message>
        <source>All features</source>
        <translation>Öll sérkenni</translation>
    </message>
    <message>
        <source>Outcoloring modes</source>
        <translation>Útlitar-hamar</translation>
    </message>
    <message>
        <source>Incoloring modes</source>
        <translation>Innlitar-hamar</translation>
    </message>
    <message>
        <source>True-color coloring modes</source>
        <translation>Sannlitar litavals hamur</translation>
    </message>
    <message>
        <source>Planes</source>
        <translation>Sléttur</translation>
    </message>
    <message>
        <source>Animations and position files</source>
        <translation>Hreyfimyndir og stöðu-skjöl</translation>
    </message>
    <message>
        <source>Random palettes</source>
        <translation>Slembið litaval</translation>
    </message>
    <message>
        <source>Other noteworthy features</source>
        <translation>Önnur mikilvæg sérkenni</translation>
    </message>
    <message>
        <source>The definition and fractal dimension</source>
        <translation>Skilgreining og rúmvídd brota</translation>
    </message>
    <message>
        <source>Escape time fractals</source>
        <translation>Flóttatíma brotar (escape time fractals)</translation>
    </message>
    <message>
        <source>Triceratops and Catseye fractals</source>
        <translation>Triceratop og Kattarauga brotar</translation>
    </message>
    <message>
        <source>Mandelbar, Lambda, Manowar and Spider</source>
        <translation>Mandelbar, Lambda, Manowar og Könguló</translation>
    </message>
    <message>
        <source>Sierpinski Gasket, S.Carpet, Koch Snowflake</source>
        <translation>Sierpinski þríhyrningur, S.Teppi, Koch snjókornið</translation>
    </message>
    <message>
        <source>What&apos;s new in 3.0?</source>
        <translation>Hvað er nýtt í 3.0?</translation>
    </message>
    <message>
        <source>What&apos;s new in 4.0?</source>
        <translation type="unfinished">Hvað er nýtt í 3.0? {4.0??}</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Hætta</translation>
    </message>
    <message>
        <source>Message Font...</source>
        <translation>Leturgerð skilaboða...</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Alskjár</translation>
    </message>
    <message>
        <source>Send Feedback</source>
        <translation>Senda viðbrögð</translation>
    </message>
    <message>
        <source>Get Updates</source>
        <translation>Fá uppfærslu</translation>
    </message>
    <message>
        <source>User Forum</source>
        <translation>Notendasvæði (forum)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Um</translation>
    </message>
    <message>
        <source>Cartesian Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PNG</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Render Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Palette Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Palette Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Palette Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Palette Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Info on current fractal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy position URL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Message</name>
    <message>
        <source>Boundary trace</source>
        <translation>Jaðarspor</translation>
    </message>
    <message>
        <source>Solid guessing 1</source>
        <translation>Gisk rúmskika 1</translation>
    </message>
    <message>
        <source>Solid guessing</source>
        <translation>Gisk rúmskika</translation>
    </message>
    <message>
        <source>Out of memory</source>
        <translation>Minni búið</translation>
    </message>
    <message>
        <source>Unbalanced parentheses</source>
        <translation>Vantar sviga</translation>
    </message>
    <message>
        <source>Unknown function: %s</source>
        <translation>Óþekkt fall: %s</translation>
    </message>
    <message>
        <source>Invalid number: %s</source>
        <translation>Óþekkt stærð: %s</translation>
    </message>
    <message>
        <source>Unknown variable: %s</source>
        <translation>Óþekkt breyta: %s</translation>
    </message>
    <message>
        <source>Invalid operator: %s</source>
        <translation>Óþekktur virki: %s</translation>
    </message>
    <message>
        <source>Internal error occurred in formula: %s</source>
        <translation>Innri villa kom upp í formúlu: %s</translation>
    </message>
    <message>
        <source>Function has incorrect parameter count: %s</source>
        <translation>Fall inniheldur ranga fjöldatölu stika: %s</translation>
    </message>
    <message>
        <source>Empty formula</source>
        <translation>Tóm formúla</translation>
    </message>
    <message>
        <source>XaoS must restart to change the thread count.</source>
        <translation>Endurræsa þarf XaoS til að breyta talningu þráða.</translation>
    </message>
    <message>
        <source>Do you want to quit now?</source>
        <translation>Viltu hætta?</translation>
    </message>
    <message>
        <source>Replay disabled at line %i</source>
        <translation>Endurspilun stöðvuð í línu %i</translation>
    </message>
    <message>
        <source>Initializing</source>
        <translation>Frumstilli</translation>
    </message>
    <message>
        <source>Loading catalogs</source>
        <translation>Hleð efnisskrá</translation>
    </message>
    <message>
        <source>Processing command line options</source>
        <translation>Vinn úr möguleikum skipunarlínu</translation>
    </message>
    <message>
        <source>Enabling animation replay
</source>
        <translation>Geri endurspilun hreyfimyndar mögulega
</translation>
    </message>
    <message>
        <source>Entering calculation loop!</source>
        <translation>Hef útreikning lykkju!</translation>
    </message>
    <message>
        <source>Rendering frame %i...</source>
        <translation>Geng frá ramma %i...</translation>
    </message>
    <message>
        <source>Linking frame %i to %i...</source>
        <translation>Tengi ramma %i til %i...</translation>
    </message>
    <message>
        <source>Calculation finished</source>
        <translation>Útreikningum lokið</translation>
    </message>
    <message>
        <source>Preparing first image</source>
        <translation>Undirbý fyrstu mynd</translation>
    </message>
    <message>
        <source>File %s loaded.</source>
        <translation>Skjal %s fullhlaðið.</translation>
    </message>
    <message>
        <source>Saving image...</source>
        <translation>Vista mynd...</translation>
    </message>
    <message>
        <source>Save interrupted</source>
        <translation>Vistun truflaðist</translation>
    </message>
    <message>
        <source>File %s saved.</source>
        <translation>Skjal %s vistaðist.</translation>
    </message>
    <message>
        <source>Can not open file</source>
        <translation>Get ekki opnað skjal</translation>
    </message>
    <message>
        <source>Recording to file %s enabled.</source>
        <translation>Skráning í skjal %s óvirk.</translation>
    </message>
    <message>
        <source>%s %.2f times (%.1fE) %2.2f frames/sec %c %i %i %i %u            </source>
        <translation>%s %.2f sinnum (%.1fE) %2.2f rammar/sek %c %i %i %i %u            </translation>
    </message>
    <message>
        <source>unzoomed</source>
        <translation>óþysjað</translation>
    </message>
    <message>
        <source>zoomed</source>
        <translation>þysjað</translation>
    </message>
    <message>
        <source>framerate:%f
</source>
        <translation>rammatíðni: %f
</translation>
    </message>
    <message>
        <source>Fractal name:%s</source>
        <translation>Nafn brota: %s</translation>
    </message>
    <message>
        <source>Fractal type:%s</source>
        <translation>Gerð brota: %s</translation>
    </message>
    <message>
        <source>Mandelbrot</source>
        <translation>Mandelbrot</translation>
    </message>
    <message>
        <source>Julia</source>
        <translation>Júlía</translation>
    </message>
    <message>
        <source>Formula:%s</source>
        <translation>Formúla: %s</translation>
    </message>
    <message>
        <source>View:[%1.12f,%1.12f]</source>
        <translation>Sýn:[%1.12f,%1.12f]</translation>
    </message>
    <message>
        <source>size:[%1.12f,%1.12f]</source>
        <translation>stærð:[%1.12f,%1.12f]</translation>
    </message>
    <message>
        <source>Rotation:%4.2f   Screen size:%i:%i</source>
        <translation>Snúningur:%4.2f   Stærð skjás:%i:%i</translation>
    </message>
    <message>
        <source>Iterations:%-4u Palette size:%i</source>
        <translation>Ítranir:%-4u Stærð litavals:%i</translation>
    </message>
    <message>
        <source>Bailout:%4.2f</source>
        <translation type="unfinished">Stöðvunargildi</translation>
    </message>
    <message>
        <source>Autopilot:%-4s  Plane:%s</source>
        <translation>Sjálfvirk stilling:%-4s  Slétta:%s</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Virkja</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Afvirkja</translation>
    </message>
    <message>
        <source>incoloring:%s    outcoloring:%s</source>
        <translation>innlitun:%s    útlitun:%s</translation>
    </message>
    <message>
        <source>zoomspeed:%f</source>
        <translation>þysjunarhraði:%f</translation>
    </message>
    <message>
        <source>Parameter:none</source>
        <translation>Stiki:enginn</translation>
    </message>
    <message>
        <source>Parameter:[%f,%f]</source>
        <translation>Stiki:[%f,%f]</translation>
    </message>
    <message>
        <source>Thank you for using XaoS
</source>
        <translation>Takk fyrir að nota XaoS
</translation>
    </message>
    <message>
        <source>Enabling: %s. </source>
        <translation>Virkja: %s. </translation>
    </message>
    <message>
        <source>Disabling: %s. </source>
        <translation>Afvirkja: %s. </translation>
    </message>
    <message>
        <source>Skipping, please wait...</source>
        <translation>Sleppi, vinsamlega bíðið...</translation>
    </message>
    <message>
        <source>Letters per second %i  </source>
        <translation>Stafir á sekúndu %i  </translation>
    </message>
    <message>
        <source>Rotation speed:%2.2f degrees per second </source>
        <translation>Snúningshraði: %2.2f gráður á sekúndu </translation>
    </message>
    <message>
        <source>Iterations: %i   </source>
        <translation>Ítranir: %i   </translation>
    </message>
    <message>
        <source>Cycling speed: %i   </source>
        <translation>Snúningshraði: %i   </translation>
    </message>
    <message>
        <source>speed:%2.2f </source>
        <translation>hraði:%2.2f </translation>
    </message>
    <message>
        <source>Please wait while calculating %s</source>
        <translation>Vinisamlega bíðið meðan útreikningar standa yfir %s</translation>
    </message>
    <message>
        <source>Welcome to XaoS version %s</source>
        <translation>Velkomin í XaoS útg. %s</translation>
    </message>
    <message>
        <source>File %s opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XaoS must restart to change the language.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard set to %s.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse:[%1.12f,%1.12f]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
